<?php

namespace Litecms\Trader\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Trader\Http\Requests\TraderRequest;
use Litecms\Trader\Models\Trader;

/**
 * Admin web controller class.
 */
class TraderWorkflowController extends BaseController
{

    /**
     * Workflow controller function for trader.
     *
     * @param Model   $trader
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TraderRequest $request, Trader $trader, $step)
    {

        try {

            $trader->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('trader::trader.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/trader/trader/' . $trader->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/trader/trader/' . $trader->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for trader.
     *
     * @param Model   $trader
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Trader $trader, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $trader->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('trader::trader.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('trader::admin.trader.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('trader::admin.trader.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('trader::admin.trader.message', $data)->render();

        }

    }
}
