<?php

namespace Litecms\Trader\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Trader\Models\Trader;

class TraderPolicy
{

    /**
     * Determine if the given user can view the trader.
     *
     * @param UserPolicy $user
     * @param Trader $trader
     *
     * @return bool
     */
    public function view(UserPolicy $user, Trader $trader)
    {
        if ($user->canDo('trader.trader.view') && $user->isAdmin()) {
            return true;
        }

        return $trader->user_id == user_id() && $trader->user_type == user_type();
    }

    /**
     * Determine if the given user can create a trader.
     *
     * @param UserPolicy $user
     * @param Trader $trader
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('trader.trader.create');
    }

    /**
     * Determine if the given user can update the given trader.
     *
     * @param UserPolicy $user
     * @param Trader $trader
     *
     * @return bool
     */
    public function update(UserPolicy $user, Trader $trader)
    {
        if ($user->canDo('trader.trader.edit') && $user->isAdmin()) {
            return true;
        }

        return $trader->user_id == user_id() && $trader->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given trader.
     *
     * @param UserPolicy $user
     * @param Trader $trader
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Trader $trader)
    {
        return $trader->user_id == user_id() && $trader->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given trader.
     *
     * @param UserPolicy $user
     * @param Trader $trader
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Trader $trader)
    {
        if ($user->canDo('trader.trader.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given trader.
     *
     * @param UserPolicy $user
     * @param Trader $trader
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Trader $trader)
    {
        if ($user->canDo('trader.trader.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
