<?php

namespace Litecms\Trader\Providers;

use Illuminate\Support\ServiceProvider;

class TraderServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'trader');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'trader');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerTrader();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerTrader()
    {
        $this->app->bind('trader', function($app) {
            return new Trader($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Trader', 'Lavalite\Trader\Facades\Trader');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.trader', function ($app) {
            return $this->app->make('Litecms\Trader\Trader');
        });

                // Bind Trader to repository
        $this->app->bind(
            'Litecms\Trader\Interfaces\TraderRepositoryInterface',
            \Litecms\Trader\Repositories\Eloquent\TraderRepository::class
        );

        $this->app->register(\Litecms\Trader\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Trader\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Trader\Providers\RouteServiceProvider::class);
                $this->app->register(\Litecms\Trader\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and trader's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/trader.php', 'trader'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeTrader::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.trader'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/trader.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/trader')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/trader')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
