<?php

namespace Litecms\Trader\Workflow;

use Litecms\Trader\Models\Trader;
use Validator;

class TraderValidator
{

    /**
     * Determine if the given trader is valid for complete status.
     *
     * @param Trader $trader
     *
     * @return bool / Validator
     */
    public function complete(Trader $trader)
    {
        return Validator::make($trader->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given trader is valid for verify status.
     *
     * @param Trader $trader
     *
     * @return bool / Validator
     */
    public function verify(Trader $trader)
    {
        return Validator::make($trader->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given trader is valid for approve status.
     *
     * @param Trader $trader
     *
     * @return bool / Validator
     */
    public function approve(Trader $trader)
    {
        return Validator::make($trader->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given trader is valid for publish status.
     *
     * @param Trader $trader
     *
     * @return bool / Validator
     */
    public function publish(Trader $trader)
    {
        return Validator::make($trader->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given trader is valid for archive status.
     *
     * @param Trader $trader
     *
     * @return bool / Validator
     */
    public function archive(Trader $trader)
    {
        return Validator::make($trader->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given trader is valid for unpublish status.
     *
     * @param Trader $trader
     *
     * @return bool / Validator
     */
    public function unpublish(Trader $trader)
    {
        return Validator::make($trader->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
